#
# spec file for package coreutils (Version 8.6)
#
# Copyright (c) 2010 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#



Name:           coreutils
Summary:        GNU Core Utilities
BuildRequires:  help2man libacl-devel libcap-devel libselinux-devel pam-devel xz
Url:            http://www.gnu.org/software/coreutils/
License:        GFDLv1.2 ; GPLv2+ ; GPLv3+
Group:          System/Base
Version:        8.6
Release:        2
Provides:       fileutils = %{version}, sh-utils = %{version}, stat = %version}, textutils = %{version}, mktemp = %{version}
Obsoletes:      fileutils < %{version}, sh-utils < %{version}, stat < %version}, textutils < %{version}, mktemp < %{version}
Obsoletes:      libselinux <= 1.23.11-3 libselinux-32bit = 9 libselinux-64bit = 9 libselinux-x86 = 9
AutoReqProv:    on
PreReq:         %{install_info_prereq}
Recommends:     %{name}-lang = %version
Requires:       pam >= 1.1.1.90
Source:         coreutils-%{version}.tar.xz
Source1:        su.pamd
Source2:        su.default
Source3:        baselibs.conf
Patch0:         coreutils-%{version}.patch
Patch1:         coreutils-no_hostname_and_hostid.patch
Patch2:         coreutils-gl_printf_safe.patch
Patch4:         coreutils-8.6-i18n.patch
Patch5:         coreutils-i18n-uninit.patch
Patch6:         coreutils-i18n-infloop.patch
Patch8:         coreutils-sysinfo.patch
Patch16:        coreutils-invalid-ids.patch
Patch20:        coreutils-8.6-pam-support-for-su.diff
Patch21:        coreutils-8.6-update-man-page-for-pam.diff
Patch22:        coreutils-8.6-log-all-su-attempts.diff
Patch23:        coreutils-8.6-set-sane-default-path.diff
Patch24:        coreutils-8.6-honor-settings-in-etc-default-su-resp-etc-login.defs.diff
Patch25:        coreutils-8.6-make-sure-sbin-resp-usr-sbin-are-in-PATH.diff
#
Patch30:        coreutils-8.6-compile-su-with-fpie.diff
Patch31:        coreutils-getaddrinfo.patch
Patch32:        coreutils-ptr_int_casts.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
# this will create a cycle, broken up randomly - coreutils is just too core to have other
# prerequires
#PreReq:         permissions

%description
Basic file, shell, and text manipulation utilities.  The package
contains the following programs:

[ arch base64 basename cat chcon chgrp chmod chown chroot cksum comm cp
csplit cut date dd df dir dircolors dirname du echo env expand expr
factor false fmt fold groups head id install join kill link ln logname
ls md5sum mkdir mkfifo mknod mktemp mv nice nl nohup od paste pathchk
pinky pr printenv printf ptx pwd readlink rm rmdir runcon seq sha1sum
sha224sum sha256sum sha384sum sha512sum shred shuf sleep sort split
stat stty su sum sync tac tail tee test timeout touch tr true tsort tty
uname unexpand uniq unlink uptime users vdir wc who whoami yes

%lang_package
%prep
%setup -q
%patch4
%patch5
%patch6
%patch0
%patch1
%patch2
%patch8
%patch16
%patch20 -p1
%patch21 -p1
%patch22 -p1
%patch23 -p1
%patch24 -p1
%patch25 -p1
#
%patch30 -p1
%patch31
%patch32

%build
AUTOPOINT=true autoreconf -fi
export CFLAGS="%optflags -Wall"
%configure --without-included-regex \
  	    --enable-install-program=arch,su \
	    gl_cv_func_printf_directive_n=yes \
	    gl_cv_func_isnanl_works=yes \
  	    DEFAULT_POSIX2_VERSION=199209
make %{?_smp_mflags} V=1

#%check
#if test $EUID -eq 0; then
#  su nobody -c make %{?_smp_mflags} check VERBOSE=yes V=1
#  make %{?_smp_mflags} check-root VERBOSE=yes V=1
#else
#%ifarch %arm
#  make -k %{?_smp_mflags} check VERBOSE=yes V=1 || echo make check failed
#%else
#  make %{?_smp_mflags} check VERBOSE=yes V=1
#%endif
#fi

%install
%makeinstall
test -f $RPM_BUILD_ROOT%{_bindir}/su || \
  install src/su $RPM_BUILD_ROOT%{_bindir}/su
install -d $RPM_BUILD_ROOT/bin
for i in arch basename cat chgrp chmod chown cp date dd df echo false kill ln ls mkdir mknod mktemp mv pwd rm rmdir sleep sort stat stty su sync touch true uname readlink md5sum
do
	mv $RPM_BUILD_ROOT%{_bindir}/$i $RPM_BUILD_ROOT/bin/$i
	test $i = su && echo -n '%%attr(4755,root,root) '
	echo /bin/$i
done > bin.files
ln -sf ../../bin/{basename,sort,stat,touch,readlink,md5sum} $RPM_BUILD_ROOT%{_bindir}
install -d -m 755 $RPM_BUILD_ROOT/etc/pam.d
install -m 644 $RPM_SOURCE_DIR/su.pamd $RPM_BUILD_ROOT/etc/pam.d/su
install -m 644 $RPM_SOURCE_DIR/su.pamd $RPM_BUILD_ROOT/etc/pam.d/su-l
install -d -m 755 $RPM_BUILD_ROOT/etc/default
install -m 644 $RPM_SOURCE_DIR/su.default $RPM_BUILD_ROOT/etc/default/su
echo '.so man1/test.1' > %{buildroot}/%{_mandir}/man1/\[.1
%find_lang %name

%post
%install_info --info-dir=%{_infodir} %{_infodir}/coreutils.info.gz
# may fail if permissions is not there, but there is no way around that
%run_permissions

%postun
%install_info_delete --info-dir=%{_infodir} %{_infodir}/coreutils.info.gz

%verifyscript
%verify_permissions -e /bin/su

%clean
rm -rf $RPM_BUILD_ROOT

%files -f bin.files
%defattr(-,root,root)
%doc README NEWS
%config /etc/pam.d/su
%config /etc/pam.d/su-l
%config(noreplace) /etc/default/su
%{_bindir}/*
%{_libdir}/%{name}
%doc %{_infodir}/coreutils.info*.gz
%doc %{_mandir}/man1/*.1.gz
%dir %{_prefix}/share/locale/*/LC_TIME

%files lang -f %name.lang
%defattr(-,root,root)

%changelog
